![](logo.png)

![](https://travis-ci.org/EGaraldi/corecon.svg?branch=master)

CoReCon: open collection of Reionization Constraints
====================================================

**CoReCon** is an open collection of constraints on various physical
quantities linked to the *Epoch of Reionization (EoR)*.

It is built to be easily complemented by contribution from the scientific
community, thanks to a simple data form that supports two different ways of
input data.

CoReCon takes care of loading and interpreting the data, and presenting them
in an organic and ready-to-use way. It also implement simple slicing capabilities,
which allow to perform simple data filtering.

See https://corecon.readthedocs.io/en/latest/ for the latest documentation.
